@@ -1,43 +1,32 @@
+import json
 from io import IOBase
 from pathlib import Path
-from typing import Any, Literal
+from typing import Any, AsyncGenerator, Generator
 
 import PIL.Image
 from pydantic import HttpUrl
 from openai.types.chat.chat_completion_reasoning_effort import ChatCompletionReasoningEffort
+from openai.types.chat.parsed_chat_completion import ParsedChatCompletionMessage
 
 from ..._resource import AsyncAPIResource, SyncAPIResource
-from ...utils.json_schema import load_json_schema, filter_auxiliary_fields_json
-from ...utils.mime import convert_mime_data_to_pil_image, prepare_mime_document
+from ...utils.mime import prepare_mime_document
 from ...utils.ai_models import assert_valid_model_extraction
+from ...utils.stream_context_managers import as_async_context_manager, as_context_manager
 from ...types.documents.create_messages import DocumentCreateInputRequest, DocumentCreateMessageRequest, DocumentMessage
-from ...types.documents.extractions import DocumentExtractRequest, RetabParsedChatCompletion
+from ...types.documents.extract import DocumentExtractRequest, RetabParsedChatCompletion, RetabParsedChatCompletionChunk, RetabParsedChoice, maybe_parse_to_pydantic
 from ...types.documents.parse import ParseRequest, ParseResult, TableParsingFormat
 from ...types.browser_canvas import BrowserCanvas
 from ...types.mime import MIMEData
 from ...types.modalities import Modality
 from ...types.ai_models import LLMModel
-from ...types.schemas.object import Schema
 from ...types.standards import PreparedRequest, FieldUnset
-
-
-def maybe_parse_to_pydantic(schema: Schema, response: RetabParsedChatCompletion, allow_partial: bool = False) -> RetabParsedChatCompletion:
-    if response.choices[0].message.content:
-        try:
-            if allow_partial:
-                response.choices[0].message.parsed = schema._partial_pydantic_model.model_validate(filter_auxiliary_fields_json(response.choices[0].message.content))
-            else:
-                response.choices[0].message.parsed = schema.pydantic_model.model_validate(filter_auxiliary_fields_json(response.choices[0].message.content))
-        except Exception:
-            pass
-    return response
-
+from ...utils.json_schema import load_json_schema, unflatten_dict
 
 class BaseDocumentsMixin:
     def _prepare_create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -62,7 +51,7 @@ class BaseDocumentsMixin:
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -99,60 +88,102 @@ class BaseDocumentsMixin:
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         model: LLMModel,
-        table_parsing_format: TableParsingFormat = "html",
-        image_resolution_dpi: int = 72,
-        browser_canvas: BrowserCanvas = "A4",
+        table_parsing_format: TableParsingFormat = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
     ) -> PreparedRequest:
         mime_document = prepare_mime_document(document)
 
-        parse_request = ParseRequest(
-            document=mime_document,
-            model=model,
-            table_parsing_format=table_parsing_format,
-            image_resolution_dpi=image_resolution_dpi,
-            browser_canvas=browser_canvas,
-        )
+        request_dict = {
+            "document": mime_document,
+            "model": model,
+        }
+        if table_parsing_format is not FieldUnset:
+            request_dict["table_parsing_format"] = table_parsing_format
+        if image_resolution_dpi is not FieldUnset:
+            request_dict["image_resolution_dpi"] = image_resolution_dpi
+        if browser_canvas is not FieldUnset:
+            request_dict["browser_canvas"] = browser_canvas
+
+        parse_request = ParseRequest(**request_dict)
         return PreparedRequest(method="POST", url="/v1/documents/parse", data=parse_request.model_dump(mode="json", exclude_unset=True), idempotency_key=idempotency_key)
 
+    def _prepare_extract(
+        self,
+        json_schema: dict[str, Any] | Path | str,
+        model: str,
+        document: Path | str | IOBase | HttpUrl | None = None,
+        documents: list[Path | str | IOBase | HttpUrl] | None = None,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        temperature: float = FieldUnset,
+        modality: Modality = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        n_consensus: int = FieldUnset,
+        stream: bool = FieldUnset,
+        store: bool = FieldUnset,
+        idempotency_key: str | None = None,
+    ) -> PreparedRequest:
+        assert_valid_model_extraction(model)
+
+        loaded_schema = load_json_schema(json_schema)
+
+        # Handle both single document and multiple documents
+        if document is not None and documents is not None:
+            raise ValueError("Cannot provide both 'document' and 'documents' parameters. Use either one.")
+
+        # Convert single document to documents list for consistency
+        if document is not None:
+            processed_documents = [prepare_mime_document(document)]
+        elif documents is not None:
+            processed_documents = [prepare_mime_document(doc) for doc in documents]
+        else:
+            raise ValueError("Must provide either 'document' or 'documents' parameter.")
+
+        # Build request dictionary with only provided fields
+        request_dict = {
+            "json_schema": loaded_schema,
+            "documents": processed_documents,
+            "model": model,
+        }
+        if stream is not FieldUnset:
+            request_dict["stream"] = stream
+        if store is not FieldUnset:
+            request_dict["store"] = store
+        if temperature is not FieldUnset:
+            request_dict["temperature"] = temperature
+        if modality is not FieldUnset:
+            request_dict["modality"] = modality
+        if reasoning_effort is not FieldUnset:
+            request_dict["reasoning_effort"] = reasoning_effort
+        if n_consensus is not FieldUnset:
+            request_dict["n_consensus"] = n_consensus
+        if image_resolution_dpi is not FieldUnset:
+            request_dict["image_resolution_dpi"] = image_resolution_dpi
+        if browser_canvas is not FieldUnset:
+            request_dict["browser_canvas"] = browser_canvas
+
+        # Validate DocumentAPIRequest data (raises exception if invalid)
+        extract_request = DocumentExtractRequest(**request_dict)
+
+        # Use the same URL as extractions.py for consistency when streaming
+        url = "/v1/documents/extractions" if stream else "/v1/documents/extract"
+        return PreparedRequest(
+            method="POST", url=url, data=extract_request.model_dump(mode="json", exclude_unset=True, exclude_defaults=True), idempotency_key=idempotency_key
+        )
+
 
 class Documents(SyncAPIResource, BaseDocumentsMixin):
     """Documents API wrapper"""
 
     def __init__(self, client: Any) -> None:
         super().__init__(client=client)
-        # self.extractions_api = Extractions(client=client)
-        # self.batch = Batch(client=client)
-
-    def correct_image_orientation(self, document: Path | str | IOBase | MIMEData | PIL.Image.Image) -> PIL.Image.Image:
-        """Corrects the orientation of an image using the Retab API.
-
-        This method takes an image in various formats and returns a PIL Image with corrected orientation.
-        Useful for handling images from mobile devices or cameras that may have incorrect EXIF orientation.
-
-        Args:
-            image: The input image to correct. Can be:
-                - A file path (Path or str)
-                - A file-like object (IOBase)
-                - A MIMEData object
-                - A PIL Image object
-
-        Returns:
-            PIL.Image.Image: The orientation-corrected image as a PIL Image object
-
-        Raises:
-            ValueError: If the input is not a valid image
-            RetabAPIError: If the API request fails
-        """
-        request = self._prepare_correct_image_orientation(document)
-        response = self._client._prepared_request(request)
-        mime_response = MIMEData.model_validate(response["document"])
-        return convert_mime_data_to_pil_image(mime_response)
 
     def create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -182,7 +213,7 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -227,7 +258,7 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
-        store: bool = False,
+        store: bool = FieldUnset,
     ) -> RetabParsedChatCompletion:
         """
         Process one or more documents using the Retab API for structured data extraction.
@@ -256,62 +287,138 @@ class Documents(SyncAPIResource, BaseDocumentsMixin):
             ValueError: If neither document nor documents is provided, or if both are provided
             HTTPException: If the request fails
         """
-        assert_valid_model_extraction(model)
-
-        json_schema = load_json_schema(json_schema)
-
-        # Handle both single document and multiple documents
-        if document is not None and documents is not None:
-            raise ValueError("Cannot provide both 'document' and 'documents' parameters. Use either one.")
-
-        # Convert single document to documents list for consistency
-        if document is not None:
-            processed_documents = [prepare_mime_document(document)]
-        elif documents is not None:
-            processed_documents = [prepare_mime_document(doc) for doc in documents]
-        else:
-            raise ValueError("Must provide either 'document' or 'documents' parameter.")
-
-        # Build request dictionary with only provided fields
-        request_dict = {
-            "json_schema": json_schema,
-            "documents": processed_documents,
-            "model": model,
-            "stream": False,
-            "store": store,
-        }
-        if temperature is not FieldUnset:
-            request_dict["temperature"] = temperature
-        if modality is not FieldUnset:
-            request_dict["modality"] = modality
-        if reasoning_effort is not FieldUnset:
-            request_dict["reasoning_effort"] = reasoning_effort
-        if n_consensus is not FieldUnset:
-            request_dict["n_consensus"] = n_consensus
-        if image_resolution_dpi is not FieldUnset:
-            request_dict["image_resolution_dpi"] = image_resolution_dpi
-        if browser_canvas is not FieldUnset:
-            request_dict["browser_canvas"] = browser_canvas
-
-        # Validate DocumentAPIRequest data (raises exception if invalid)
-        request = DocumentExtractRequest(**request_dict)
-
-        prepared_request = PreparedRequest(
-            method="POST", url="/v1/documents/extract", data=request.model_dump(mode="json", exclude_unset=True, exclude_defaults=True), idempotency_key=idempotency_key
+        request = self._prepare_extract(
+            json_schema=json_schema,
+            model=model,
+            document=document,
+            documents=documents,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            temperature=temperature,
+            modality=modality,
+            reasoning_effort=reasoning_effort,
+            n_consensus=n_consensus,
+            store=store,
+            idempotency_key=idempotency_key,
         )
+        response = self._client._prepared_request(request)
 
-        response = self._client._prepared_request(prepared_request)
+        return maybe_parse_to_pydantic(load_json_schema(json_schema), RetabParsedChatCompletion.model_validate(response))
 
-        schema = Schema(json_schema=load_json_schema(json_schema))
-        return maybe_parse_to_pydantic(schema, RetabParsedChatCompletion.model_validate(response))
+    @as_context_manager
+    def extract_stream(
+        self,
+        json_schema: dict[str, Any] | Path | str,
+        model: str,
+        document: Path | str | IOBase | HttpUrl | None = None,
+        documents: list[Path | str | IOBase | HttpUrl] | None = None,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        temperature: float = FieldUnset,
+        modality: Modality = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        n_consensus: int = FieldUnset,
+        idempotency_key: str | None = None,
+        store: bool = FieldUnset,
+    ) -> Generator[RetabParsedChatCompletion, None, None]:
+        """
+        Process one or more documents using the Retab API with streaming enabled.
+
+        Args:
+            json_schema: JSON schema defining the expected data structure
+            model: The AI model to use for processing
+            document: Single document to process (use either this or documents, not both)
+            documents: List of documents to process (use either this or document, not both)
+            image_resolution_dpi: Optional image resolution DPI.
+            browser_canvas: Optional browser canvas size.
+            temperature: Model temperature setting (0-1)
+            modality: Modality of the document (e.g., native)
+            reasoning_effort: The effort level for the model to reason about the input data.
+            n_consensus: Number of consensus extractions to perform (default: 1 which computes a single extraction and the likelihoods comes from the model logprobs)
+            idempotency_key: Idempotency key for request
+            store: Whether to store the document in the Retab database
+
+        Returns:
+            Generator[RetabParsedChatCompletion]: Stream of parsed responses
+        Raises:
+            ValueError: If neither document nor documents is provided, or if both are provided
+            HTTPException: If the request fails
+        Usage:
+        ```python
+        # Single document
+        with retab.documents.extract_stream(json_schema, model, document=document) as stream:
+            for response in stream:
+                print(response)
+
+        # Multiple documents
+        with retab.documents.extract_stream(json_schema, model, documents=[doc1, doc2]) as stream:
+            for response in stream:
+                print(response)
+        ```
+        """
+        request = self._prepare_extract(
+            json_schema=json_schema,
+            document=document,
+            documents=documents,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            model=model,
+            temperature=temperature,
+            modality=modality,
+            reasoning_effort=reasoning_effort,
+            stream=True,
+            n_consensus=n_consensus,
+            store=store,
+            idempotency_key=idempotency_key,
+        )
+        schema = load_json_schema(json_schema)
+
+        # Request the stream and return a context manager
+        ui_parsed_chat_completion_cum_chunk: RetabParsedChatCompletionChunk | None = None
+        # Initialize the RetabParsedChatCompletion object
+        ui_parsed_completion: RetabParsedChatCompletion = RetabParsedChatCompletion(
+            id="",
+            created=0,
+            model="",
+            object="chat.completion",
+            likelihoods={},
+            choices=[
+                RetabParsedChoice(
+                    index=0,
+                    message=ParsedChatCompletionMessage(content="", role="assistant"),
+                    finish_reason=None,
+                    logprobs=None,
+                )
+            ],
+        )
+        for chunk_json in self._client._prepared_request_stream(request):
+            if not chunk_json:
+                continue
+            ui_parsed_chat_completion_cum_chunk = RetabParsedChatCompletionChunk.model_validate(chunk_json).chunk_accumulator(ui_parsed_chat_completion_cum_chunk)
+            # Basic stuff
+            ui_parsed_completion.id = ui_parsed_chat_completion_cum_chunk.id
+            ui_parsed_completion.created = ui_parsed_chat_completion_cum_chunk.created
+            ui_parsed_completion.model = ui_parsed_chat_completion_cum_chunk.model
+            # Update the ui_parsed_completion object
+            parsed = unflatten_dict(ui_parsed_chat_completion_cum_chunk.choices[0].delta.flat_parsed)
+            likelihoods = unflatten_dict(ui_parsed_chat_completion_cum_chunk.choices[0].delta.flat_likelihoods)
+            ui_parsed_completion.choices[0].message.content = json.dumps(parsed)
+            ui_parsed_completion.choices[0].message.parsed = parsed
+            ui_parsed_completion.likelihoods = likelihoods
+
+            yield maybe_parse_to_pydantic(schema, ui_parsed_completion, allow_partial=True)
+
+        # change the finish_reason to stop
+        ui_parsed_completion.choices[0].finish_reason = "stop"
+        yield maybe_parse_to_pydantic(schema, ui_parsed_completion)
 
     def parse(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         model: LLMModel,
-        table_parsing_format: TableParsingFormat = "html",
-        image_resolution_dpi: int = 72,
-        browser_canvas: BrowserCanvas = "A4",
+        table_parsing_format: TableParsingFormat = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
     ) -> ParseResult:
         """
@@ -356,7 +463,7 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
     async def create_messages(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -388,7 +495,7 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         json_schema: dict[str, Any] | Path | str,
-        modality: Modality = "native",
+        modality: Modality = FieldUnset,
         image_resolution_dpi: int = FieldUnset,
         browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
@@ -420,31 +527,6 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         response = await self._client._prepared_request(request)
         return DocumentMessage.model_validate(response)
 
-    async def correct_image_orientation(self, document: Path | str | IOBase | MIMEData | PIL.Image.Image) -> PIL.Image.Image:
-        """Corrects the orientation of an image using the Retab API asynchronously.
-
-        This method takes an image in various formats and returns a PIL Image with corrected orientation.
-        Useful for handling images from mobile devices or cameras that may have incorrect EXIF orientation.
-
-        Args:
-            image: The input image to correct. Can be:
-                - A file path (Path or str)
-                - A file-like object (IOBase)
-                - A MIMEData object
-                - A PIL Image object
-
-        Returns:
-            PIL.Image.Image: The orientation-corrected image as a PIL Image object
-
-        Raises:
-            ValueError: If the input is not a valid image
-            RetabAPIError: If the API request fails
-        """
-        request = self._prepare_correct_image_orientation(document)
-        response = await self._client._prepared_request(request)
-        mime_response = MIMEData.model_validate(response["document"])
-        return convert_mime_data_to_pil_image(mime_response)
-
     async def extract(
         self,
         json_schema: dict[str, Any] | Path | str,
@@ -458,7 +540,7 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
         reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
         n_consensus: int = FieldUnset,
         idempotency_key: str | None = None,
-        store: bool = False,
+        store: bool = FieldUnset,
     ) -> RetabParsedChatCompletion:
         """
         Process one or more documents using the Retab API for structured data extraction asynchronously.
@@ -487,62 +569,137 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             ValueError: If neither document nor documents is provided, or if both are provided
             HTTPException: If the request fails
         """
-        assert_valid_model_extraction(model)
+        request = self._prepare_extract(
+            json_schema=json_schema,
+            model=model,
+            document=document,
+            documents=documents,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            temperature=temperature,
+            modality=modality,
+            reasoning_effort=reasoning_effort,
+            n_consensus=n_consensus,
+            store=store,
+            idempotency_key=idempotency_key,
+        )
+        response = await self._client._prepared_request(request)
 
-        json_schema = load_json_schema(json_schema)
+        return maybe_parse_to_pydantic(load_json_schema(json_schema), RetabParsedChatCompletion.model_validate(response))
 
-        # Handle both single document and multiple documents
-        if document is not None and documents is not None:
-            raise ValueError("Cannot provide both 'document' and 'documents' parameters. Use either one.")
+    @as_async_context_manager
+    async def extract_stream(
+        self,
+        json_schema: dict[str, Any] | Path | str,
+        model: str,
+        document: Path | str | IOBase | HttpUrl | None = None,
+        documents: list[Path | str | IOBase | HttpUrl] | None = None,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
+        temperature: float = FieldUnset,
+        modality: Modality = FieldUnset,
+        reasoning_effort: ChatCompletionReasoningEffort = FieldUnset,
+        n_consensus: int = FieldUnset,
+        idempotency_key: str | None = None,
+        store: bool = FieldUnset,
+    ) -> AsyncGenerator[RetabParsedChatCompletion, None]:
+        """
+        Extract structured data from one or more documents asynchronously with streaming.
 
-        # Convert single document to documents list for consistency
-        if document is not None:
-            processed_documents = [prepare_mime_document(document)]
-        elif documents is not None:
-            processed_documents = [prepare_mime_document(doc) for doc in documents]
-        else:
-            raise ValueError("Must provide either 'document' or 'documents' parameter.")
+        Args:
+            json_schema: JSON schema defining the expected data structure.
+            model: The AI model to use.
+            document: Single document to process (use either this or documents, not both)
+            documents: List of documents to process (use either this or document, not both)
+            image_resolution_dpi: Optional image resolution DPI.
+            browser_canvas: Optional browser canvas size.
+            temperature: Model temperature setting (0-1).
+            modality: Modality of the document (e.g., native).
+            reasoning_effort: The effort level for the model to reason about the input data.
+            n_consensus: Number of consensus extractions to perform (default: 1 which computes a single extraction and the likelihoods comes from the model logprobs)
+            idempotency_key: Idempotency key for request
+            store: Whether to store the document in the Retab database
+        Returns:
+            AsyncGenerator[RetabParsedChatCompletion, None]: Stream of parsed responses.
+        Raises:
+            ValueError: If neither document nor documents is provided, or if both are provided
 
-        # Build request dictionary with only provided fields
-        request_dict = {
-            "json_schema": json_schema,
-            "documents": processed_documents,
-            "model": model,
-            "stream": False,
-            "store": store,
-        }
-        if temperature is not FieldUnset:
-            request_dict["temperature"] = temperature
-        if modality is not FieldUnset:
-            request_dict["modality"] = modality
-        if reasoning_effort is not FieldUnset:
-            request_dict["reasoning_effort"] = reasoning_effort
-        if n_consensus is not FieldUnset:
-            request_dict["n_consensus"] = n_consensus
-        if image_resolution_dpi is not FieldUnset:
-            request_dict["image_resolution_dpi"] = image_resolution_dpi
-        if browser_canvas is not FieldUnset:
-            request_dict["browser_canvas"] = browser_canvas
+        Usage:
+        ```python
+        # Single document
+        async with retab.documents.extract_stream(json_schema, model, document=document) as stream:
+            async for response in stream:
+                print(response)
 
-        # Validate DocumentAPIRequest data (raises exception if invalid)
-        request = DocumentExtractRequest(**request_dict)
-
-        prepared_request = PreparedRequest(
-            method="POST", url="/v1/documents/extract", data=request.model_dump(mode="json", exclude_unset=True, exclude_defaults=True), idempotency_key=idempotency_key
+        # Multiple documents
+        async with retab.documents.extract_stream(json_schema, model, documents=[doc1, doc2]) as stream:
+            async for response in stream:
+                print(response)
+        ```
+        """
+        request = self._prepare_extract(
+            json_schema=json_schema,
+            document=document,
+            documents=documents,
+            image_resolution_dpi=image_resolution_dpi,
+            browser_canvas=browser_canvas,
+            model=model,
+            temperature=temperature,
+            modality=modality,
+            reasoning_effort=reasoning_effort,
+            stream=True,
+            n_consensus=n_consensus,
+            store=store,
+            idempotency_key=idempotency_key,
+        )
+        schema = load_json_schema(json_schema)
+        ui_parsed_chat_completion_cum_chunk: RetabParsedChatCompletionChunk | None = None
+        # Initialize the RetabParsedChatCompletion object
+        ui_parsed_completion: RetabParsedChatCompletion = RetabParsedChatCompletion(
+            id="",
+            created=0,
+            model="",
+            object="chat.completion",
+            likelihoods={},
+            choices=[
+                RetabParsedChoice(
+                    index=0,
+                    message=ParsedChatCompletionMessage(content="", role="assistant"),
+                    finish_reason=None,
+                    logprobs=None,
+                )
+            ],
         )
 
-        response = await self._client._prepared_request(prepared_request)
+        async for chunk_json in self._client._prepared_request_stream(request):
+            if not chunk_json:
+                continue
+            ui_parsed_chat_completion_cum_chunk = RetabParsedChatCompletionChunk.model_validate(chunk_json).chunk_accumulator(ui_parsed_chat_completion_cum_chunk)
+            # Basic stuff
+            ui_parsed_completion.id = ui_parsed_chat_completion_cum_chunk.id
+            ui_parsed_completion.created = ui_parsed_chat_completion_cum_chunk.created
+            ui_parsed_completion.model = ui_parsed_chat_completion_cum_chunk.model
 
-        schema = Schema(json_schema=load_json_schema(json_schema))
-        return maybe_parse_to_pydantic(schema, RetabParsedChatCompletion.model_validate(response))
+            # Update the ui_parsed_completion object
+            parsed = unflatten_dict(ui_parsed_chat_completion_cum_chunk.choices[0].delta.flat_parsed)
+            likelihoods = unflatten_dict(ui_parsed_chat_completion_cum_chunk.choices[0].delta.flat_likelihoods)
+            ui_parsed_completion.choices[0].message.content = json.dumps(parsed)
+            ui_parsed_completion.choices[0].message.parsed = parsed
+            ui_parsed_completion.likelihoods = likelihoods
+
+            yield maybe_parse_to_pydantic(schema, ui_parsed_completion, allow_partial=True)
+
+        # change the finish_reason to stop
+        ui_parsed_completion.choices[0].finish_reason = "stop"
+        yield maybe_parse_to_pydantic(schema, ui_parsed_completion)
 
     async def parse(
         self,
         document: Path | str | IOBase | MIMEData | PIL.Image.Image | HttpUrl,
         model: LLMModel,
-        table_parsing_format: TableParsingFormat = "html",
-        image_resolution_dpi: int = 72,
-        browser_canvas: BrowserCanvas = "A4",
+        table_parsing_format: TableParsingFormat = FieldUnset,
+        image_resolution_dpi: int = FieldUnset,
+        browser_canvas: BrowserCanvas = FieldUnset,
         idempotency_key: str | None = None,
     ) -> ParseResult:
         """
@@ -555,7 +712,7 @@ class AsyncDocuments(AsyncAPIResource, BaseDocumentsMixin):
             document: The document to parse. Can be a file path (Path or str), file-like object, MIMEData, PIL Image, or URL.
             model: The AI model to use for document parsing.
             table_parsing_format: Format for parsing tables. Options: "html", "json", "yaml", "markdown". Defaults to "html".
-            image_resolution_dpi: DPI for image processing. Defaults to 72.
+            image_resolution_dpi: DPI for image processing. Defaults to 96.
             browser_canvas: Canvas size for document rendering. Defaults to "A4".
             idempotency_key: Optional idempotency key for the request.
 
