@@ -6,10 +6,10 @@ from ..._resource import AsyncAPIResource, SyncAPIResource
 from ...types.browser_canvas import BrowserCanvas
 from ...types.projects import CreateIterationRequest, Iteration, ProcessIterationRequest, IterationDocumentStatusResponse, PatchIterationRequest
 from ...types.inference_settings import InferenceSettings
-from ...types.metrics import DistancesResult
+from ...types.projects.metrics import DistancesResult
 from ...types.modalities import Modality
 from ...types.standards import DeleteResponse, PreparedRequest, FieldUnset
-from ...types.documents.extractions import RetabParsedChatCompletion
+from ...types.documents.extract import RetabParsedChatCompletion
 
 
 class IterationsMixin:
@@ -337,7 +337,7 @@ class AsyncIterations(AsyncAPIResource, IterationsMixin):
         temperature: float = 0.0,
         modality: Modality = "native",
         json_schema: Optional[Dict[str, Any]] = None,
-        reasoning_effort: ChatCompletionReasoningEffort = "medium",
+        reasoning_effort: ChatCompletionReasoningEffort = "minimal",
         image_resolution_dpi: int = 96,
         browser_canvas: BrowserCanvas = "A4",
         n_consensus: int = 1,
