@@ -12,8 +12,8 @@ class GenerateSchemaRequest(BaseModel):
     documents: list[MIMEData]
     model: str = "gpt-4o-mini"
     temperature: float = 0.0
-    reasoning_effort: ChatCompletionReasoningEffort = "medium"
-    modality: Modality
+    reasoning_effort: ChatCompletionReasoningEffort = "minimal"
+    modality: Modality = "native_fast"
     instructions: str | None = None
     """The modality of the document to load."""
     image_resolution_dpi: int = Field(default=96, description="Resolution of the image sent to the LLM")
@@ -24,12 +24,4 @@ class GenerateSchemaRequest(BaseModel):
     """The image operations to apply to the document."""
 
     stream: bool = False
-    """Whether to stream the response."""
-
-
-class GenerateSystemPromptRequest(GenerateSchemaRequest):
-    """
-    The request body for generating a system prompt for a JSON Schema.
-    """
-
-    json_schema: dict[str, Any]
+    """Whether to stream the response."""
\ No newline at end of file
